@@ -27,7 +27,7 @@ import sys
 class PyGTKEditor:
   def __init__(self):
     self.app = hildon.Program()
-    self.context = osso.Context('net.khertan.pygtkeditor','3.0.0', False)
+    self.context = osso.Context('net.khertan.pygtkeditor','3.0.2', False)
     self.app.set_can_hibernate(True)
     self.window_list = None
     self._manage_theme()
@@ -60,7 +60,7 @@ class PyGTKEditor:
     dialog.set_name("PyGTKEditor")                                             
     dialog.set_logo_icon_name("pygtkeditor")                                   
     dialog.set_comments('A source code editor for Maemo')                      
-    dialog.set_version("3.0.1")                                                
+    dialog.set_version("3.0.2")                                                
     dialog.set_copyright("By Benoit HERVIER (aka Khertan)")                    
     dialog.set_website("http://khertan.net/")                                  
     dialog.connect ("response", lambda d, r: d.destroy())                      
@@ -128,6 +128,10 @@ class PyGTKEditor:
       self.window_list = []
     self.window_list.append(w1)
     self.app.add_window(w1)
+    
+  def apply_prefs(self):
+    for w in self.window_list:
+      w.apply_prefs()
 
 if __name__ == "__main__":
   PyGTKEditor()
